#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 authenticate
version:              1.3.5.2
visibility:           public
id:                   authenticate-1.3.5.2-lwRAFsqBGT7afdHDGdBHL
key:                  authenticate-1.3.5.2-lwRAFsqBGT7afdHDGdBHL
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman, Hiromi Ishii, Arash Rouhani
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:             Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.

category:             Web
abi:                  66a9b6ab5df2edb3d8062915d9d476f9
exposed:              True
exposed-modules:
    Web.Authenticate.BrowserId Web.Authenticate.OpenId
    Web.Authenticate.OpenId.Providers Web.Authenticate.Rpxnow

hidden-modules:
    Web.Authenticate.Internal OpenId2.Discovery OpenId2.Normalization
    OpenId2.Types OpenId2.XRDS

import-dirs:          /usr/lib/ghc-9.6.6/site-local/authenticate-1.3.5.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/authenticate-1.3.5.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/authenticate-1.3.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-authenticate
hs-libraries:         HSauthenticate-1.3.5.2-lwRAFsqBGT7afdHDGdBHL
depends:
    aeson-2.2.2.0-4XfhhWkmpwnB2gRUwfJP7g
    attoparsec-0.14.4-IK8bf7Jdhmx3QhZQbOSRoN
    attoparsec-aeson-2.2.0.1-8oKVMuzmjvlEo7iNNx9cvG base-4.18.2.1
    blaze-builder-0.4.4.1-3pe5ffge7yT8Hv0CJmmtax bytestring-0.11.5.3
    case-insensitive-1.2.1.0-JWd1XK3KOo7EjUmuZpwp5W
    conduit-1.3.6.1-J8ndGOkTyJX5j6RwH3LErP containers-0.6.7
    html-conduit-1.3.2.2-BkZBdSZ3E67Gif9fpiqgxB
    http-conduit-2.3.9.1-J3ZuAne4JY36DPznNMquNP
    http-types-0.12.4-5vT9XdIpLUEBOtUXM3tA09
    network-uri-2.6.4.2-CMtdZ463jfq9hso9AZHHZa
    resourcet-1.3.0-BrdZatkp6QIII6Vs5RqUd1 text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-3DXXOqLpcMZGFktSBwG2cs
    xml-conduit-1.9.1.4-Jb0hi19E3BzEDUjJ8jvFtJ

haddock-interfaces:
    /usr/share/doc/haskell-authenticate/html/authenticate.haddock

haddock-html:         /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

